/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SELPAWADJUST_H
#define SELPAWADJUST_H

#include "selpaw.h"

class SelpawAdjust: public Selpaw
{
	Q_OBJECT
public:
	SelpawAdjust();
	SelpawAdjust(QSplitter*&);

public slots:
	void adjust_selpaw_ready();
	void adjust_selpaw();
	void refine_selpaw();
	void refine_selpaw_types();
	void refine_selpaw_types_final();
	void sort_selpaw_types();
	void sort_selpaw_summary();

signals:

protected:

private:
	QStringList lines_interface_name;
	QStringList lines;
	QString cumma;
	QString interface_name_this_to_be_replaced;
	QString file_interface_gen_require;
	QString line_analized2;
};

#endif
